import { Context } from "@serverless-stack/lambda/context/index.js";
import { defaultProvider } from "@aws-sdk/credential-provider-node";
import { useConfig } from "../config/index.js";
export const useAWSCredentials = Context.memo(async () => {
    const config = await useConfig();
    const provider = defaultProvider({
        profile: config.profile
    });
    return provider;
});
const useClientCache = Context.memo(() => new Map());
export async function useAWSClient(client, force = false) {
    const cache = useClientCache();
    const existing = cache.get(client.name);
    if (existing && !force)
        return existing;
    const [config, credentials] = await Promise.all([
        useConfig(),
        useAWSCredentials()
    ]);
    console.log(config, credentials);
    const result = new client({
        region: config.region,
        credentials: credentials
    });
    cache.set(client.name, result);
    return result;
}
